==> java-checks-3.13.1-sources.jar: org/sonar/java/checks/LeftCurlyBraceStartLineCheck.java <==
/*
 * SonarQube Java
 * Copyright (C) 2012-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.java.checks;

import org.sonar.api.server.rule.RulesDefinition;
import org.sonar.check.Priority;
import org.sonar.check.Rule;
import org.sonar.java.tag.Tag;
import org.sonar.plugins.java.api.tree.SyntaxToken;
import org.sonar.squidbridge.annotations.SqaleConstantRemediation;
import org.sonar.squidbridge.annotations.SqaleSubCharacteristic;

@Rule(
  key = "LeftCurlyBraceStartLineCheck",
  name = "An open curly brace should be located at the beginning of a line",
  priority = Priority.MINOR,
  tags = {Tag.CONVENTION})
@SqaleSubCharacteristic(RulesDefinition.SubCharacteristics.READABILITY)
@SqaleConstantRemediation("1min")
public class LeftCurlyBraceStartLineCheck extends LeftCurlyBraceBaseTreeVisitor {

  @Override
  protected void checkTokens(SyntaxToken lastToken, SyntaxToken openBraceToken) {
    if (lastToken.line() == openBraceToken.line()) {
      addIssue(openBraceToken, this, "Move this left curly brace to the beginning of next line of code.");
    }
  }
}

==> java-checks-7.3.0.27589-sources.jar: org/sonar/java/checks/LeftCurlyBraceStartLineCheck.java <==
/*
 * SonarQube Java
 * Copyright (C) 2012-2021 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.java.checks;

import org.sonar.check.Rule;
import org.sonar.plugins.java.api.tree.SyntaxToken;
import org.sonarsource.analyzer.commons.annotations.DeprecatedRuleKey;

@DeprecatedRuleKey(ruleKey = "LeftCurlyBraceStartLineCheck", repositoryKey = "squid")
@Rule(key = "S1106")
public class LeftCurlyBraceStartLineCheck extends LeftCurlyBraceBaseTreeVisitor {

  @Override
  protected void checkTokens(SyntaxToken lastToken, SyntaxToken openBraceToken) {
    if (lastToken.range().start().line() == openBraceToken.range().start().line()) {
      addIssue(openBraceToken, this, "Move this left curly brace to the beginning of next line of code.");
    }
  }
}
